%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%
%%% Demo file that loads an image and finds the pose of the people 
%%% specified with a list of bounding boxes around them.
%%%
%%% Copyright (C) 2011, Subhransu Maji, Lubomir Bourdev, Jitendra Malik
%%% This code is distributed with a non-commercial research license.
%%% Please see the license file license.txt included in the source directory.
%%%
%%% Please cite these papers if you use this code: 
%%% 
%%% Action recognition using a distributed representation of pose and
%%% appearance, Subhransu Maji, Lubomir Bourdev and Jitendra Malik, CVPR 2011.
%%% 
%%% Detecting people using mutually consistent poselet activations, 
%%% Lubomir Bourdev, Subhransu Maji, Thomas Brox and Jitendra Malik, ECCV
%%% 2010.
%%% 
%%% Author : Subhransu Maji  Date : March 26, 2011
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% set paths/load models
addpath poselet_detection;  
addpath liblinear/matlab;   % this is the dense liblinear version
addpath angleutil;

detection_config;

% load poselets 
load('release-data/model1200.mat');
model = output;

% load yaw prediction models
load('release-data/pose_models');

%% parameters for detection/pose estimation

faster = false; % set it to true for faster but less accurate predictions
if faster
    fprintf('warning : faster detection enabled.\n');
    config.PYRAMID_SCALE_RATIO = 2;
end

% 8 way dicrete prediction + parabolic interpolation
binctr=[-180  -135   -90   -45     0    45    90   135]; % don't change

% overlap thereshold for consitent poselet detection
pavparam.OVERLAP_THRESH = 0.2;                           % don't change

%% specify and image and bounding boxes 
I = imread('2008_000393.jpg');load('2008_000393.mat');          

%% run the pose estimation algorithm
[headyaw,torsoyaw]=image2yaw(I,bbox,model,pavparam,head_yaw_model,torso_yaw_model,binctr);

%% display the predictions
figure(1); clf;
for i = 1:size(bbox,1),
    imshow(I); 
    % draw the bounding box
    rectangle('position',bbox(i,:),'EdgeColor','y');
    rectangle('position',bbox(i,:)+[1 1 -2 -2],'EdgeColor','m');
    
    title(sprintf('head[%.2f, %.2f]\t\t\ttorso [%.2f, %.2f]',true_yaw(i,1), headyaw(i), true_yaw(i,2),torsoyaw(i)));
    pause;
end
